==> 0.3.1.tar.gz: lib/bloc/common_widgets/user_name_with_image_card.dart <==
import 'package:barcode_widget/barcode_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:loyalty_management_tool/bloc/common_widgets/user_pipulaity_card.dart';

import 'package:loyalty_management_tool/utils/localization.dart';
import 'package:loyalty_management_tool/utils/locator.dart';
import 'package:percent_indicator/linear_percent_indicator.dart';
import 'package:shared_preferences/shared_preferences.dart';

import '../../utils/basicInfo.dart';
import '../../utils/colors.dart';
import '../../utils/hexColors.dart';
import '../../utils/testcard.dart';
import '../../utils/text_styling.dart';

// ignore: must_be_immutable
class UserNameWithImageCard extends StatelessWidget {
  final userNameTextController = TextEditingController();
  final passwordTextController = TextEditingController();
  BuildContext? context;
  ProgressDialog? pr;
  SharedPreferences? prefs = locatorRewards<SharedPreferences>();
  String? title;
  String? subtitle;
  bool isFollow;
  String imageUrl;
  bool? isPersonProfile;
  Function? onClickProfile;
  int? thirdPersonId;
  int? userId;

  Null Function() callbackPicker;
  Null Function()? clicked;
  late TextStyleElements styleElements;
  String? instId;
  String? userType;
  String? ownerTye;
  String? imagePath;
  bool isUserVerified;
  bool isFromProfile;
  bool showQr;
  bool? showProgress;
  int? progress;
  Function? editCallBack;
  bool? isAdmin;
  BasicInfo basicInfo = BasicInfo();

  UserNameWithImageCard({Key? key,

    this.isAdmin,
    required this.title,
    required this.subtitle,
    required this.isFollow,
    required this.imageUrl,
    this.editCallBack,
    required this.callbackPicker,
    this.onClickProfile,
    this.thirdPersonId,
    this.userId,
    this.userType,
    this.ownerTye,
    this.clicked,
    this.isUserVerified = false,
    this.instId,
    this.imagePath,
    this.showProgress,
    this.progress,
    this.isFromProfile = false,
    this.showQr = false,
    this.isPersonProfile})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    this.context = context;
    ScreenUtil.init;

    styleElements = TextStyleElements(context);

    return Column(
      children: [
        Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: <Widget>[
            GestureDetector(
              onTap: () {
                if (onClickProfile != null) {
                  onClickProfile!();
                }
              },
              child: Container(
                margin: EdgeInsets.all(16.h),
                height: 60.w,
                width: 60.w,
                child: Stack(
                  children: [
                    Align(
                        alignment: Alignment.topLeft,
                        child: CircleAvatar(
                            key: UniqueKey(),
                            foregroundColor: HexColor(AppColors.appColorWhite),
                            backgroundColor: HexColor(AppColors.appColorWhite),
                            backgroundImage: NetworkImage(imageUrl),
                            radius: 52)),
                    Visibility(
                        visible: userType == "person",
                        child: Align(
                          alignment: Alignment.bottomRight,
                          child: Container(
                            padding: EdgeInsets.all(4.h),
                            decoration: BoxDecoration(
                                color: HexColor(AppColors.appColorWhite),
                                shape: BoxShape.circle),
                            child: Icon(
                              Icons.edit,
                              size: 12,
                              color: HexColor(AppColors.appColorBlack65),
                            ),
                          ),
                        )),
                  ],
                ),
              ),
            ),
            Expanded(
              child: GestureDetector(
                onTap: isFromProfile ? null : onClickProfile as void Function()?,
                child: Container(
                  margin: EdgeInsets.only(right: 10.h),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: <Widget>[
                      Align(
                        alignment: Alignment.topLeft,
                        child: Container(
                            child: Row(
                              mainAxisAlignment: MainAxisAlignment.start,
                              crossAxisAlignment: CrossAxisAlignment.center,
                              children: [
                                Flexible(
                                  child: Text(
                                    title ?? "",
                                    maxLines: 2,
                                    overflow: TextOverflow.ellipsis,
                                    style: styleElements
                                        .headline6ThemeScalable(context)
                                        .copyWith(
                                        fontWeight: FontWeight.bold,
                                        color: HexColor(AppColors.appColorBlack85)),
                                  ),
                                ),
                                Visibility(
                                  visible: isUserVerified,
                                  child: Padding(
                                    padding: const EdgeInsets.all(8.0),
                                    child: SizedBox(
                                      height: 16,
                                      width: 16,
                                      child: Container(
                                        child: Image(
                                          image:
                                          AssetImage('assets/appimages/check.png'),
                                        ),
                                      ),
                                    ),
                                  ),
                                )
                              ],
                            )),
                      ),
                      GestureDetector(
                        behavior: HitTestBehavior.translucent,
                        onTap: null,
                        child: Align(
                            alignment: Alignment.bottomLeft,
                            child: Row(
                              mainAxisAlignment: MainAxisAlignment.start,
                              crossAxisAlignment: CrossAxisAlignment.center,
                              children: [
                                Flexible(
                                  child: Text( "@Taraa",
                                      maxLines: 2,
                                      overflow: TextOverflow.ellipsis,
                                      style: styleElements
                                          .captionThemeScalable(context)),
                                )
                              ],
                            )),
                      ),
                      Visibility(
                        visible: showProgress ?? false,
                        child: Padding(
                          padding: const EdgeInsets.only(top: 4.0, bottom: 4.0),
                          child: Row(
                            children: [
                              Text(
                                "$progress%",
                                style: styleElements
                                    .bodyText1ThemeScalable(context)
                                    .copyWith(fontWeight: FontWeight.bold),
                              ),
                              Flexible(
                                child: LinearPercentIndicator(
                                  linearStrokeCap: LinearStrokeCap.roundAll,
                                  animation: true,
                                  animationDuration: 900,
                                  lineHeight: 12,
                                  percent: progress != null
                                      ? (progress!.toDouble() / 100)
                                      : 0.0,
                                  backgroundColor:
                                  HexColor(AppColors.pollBackground),
                                  progressColor: HexColor(AppColors.appMainColor)
                                      .withOpacity(0.75),
                                ),
                              ),
                            ],
                          ),
                        ),
                      ),

                      SizedBox(
                        height: 4,
                      )


                    ],
                  ),
                ),
              ),
            ),

          ],
        ),
        UserPopularityCard(
            textFive: '67',
            textThree: 'Status',
            textSix: '0',
            callback: () {},
            textTwo: 'Outstanding',
            textEight: 'Post Paid',
            textOne: 'Balance',
            textFour: 'Type',
            textSeven: 'Active')
      ],
    );
  }
}

==> 0.4.1.tar.gz: lib/bloc/common_widgets/user_name_with_image_card.dart <==
import 'package:barcode_widget/barcode_widget.dart';
import 'package:flutter/material.dart';

import 'package:loyalty_management_tool/bloc/common_widgets/user_pipulaity_card.dart';

import 'package:loyalty_management_tool/utils/localization.dart';
import 'package:loyalty_management_tool/utils/locator.dart';
import 'package:percent_indicator/linear_percent_indicator.dart';
import 'package:shared_preferences/shared_preferences.dart';

import '../../utils/basicInfo.dart';
import '../../utils/colors.dart';
import '../../utils/hexColors.dart';
import '../../utils/testcard.dart';
import '../../utils/text_styling.dart';

// ignore: must_be_immutable
class UserNameWithImageCard extends StatelessWidget {
  final userNameTextController = TextEditingController();
  final passwordTextController = TextEditingController();
  BuildContext? context;
  ProgressDialog? pr;
  SharedPreferences? prefs = locatorRewards<SharedPreferences>();
  String? title;
  String? subtitle;
  bool isFollow;
  String imageUrl;
  bool? isPersonProfile;
  Function? onClickProfile;
  int? thirdPersonId;
  int? userId;

  Null Function() callbackPicker;
  Null Function()? clicked;
  late TextStyleElements styleElements;
  String? instId;
  String? userType;
  String? ownerTye;
  String? imagePath;
  bool isUserVerified;
  bool isFromProfile;
  bool showQr;
  bool? showProgress;
  int? progress;
  Function? editCallBack;
  bool? isAdmin;
  BasicInfo basicInfo = BasicInfo();

  UserNameWithImageCard({Key? key,

    this.isAdmin,
    required this.title,
    required this.subtitle,
    required this.isFollow,
    required this.imageUrl,
    this.editCallBack,
    required this.callbackPicker,
    this.onClickProfile,
    this.thirdPersonId,
    this.userId,
    this.userType,
    this.ownerTye,
    this.clicked,
    this.isUserVerified = false,
    this.instId,
    this.imagePath,
    this.showProgress,
    this.progress,
    this.isFromProfile = false,
    this.showQr = false,
    this.isPersonProfile})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    this.context = context;


    styleElements = TextStyleElements(context);

    return Column(
      children: [
        Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: <Widget>[
            GestureDetector(
              onTap: () {
                if (onClickProfile != null) {
                  onClickProfile!();
                }
              },
              child: Container(
                margin: EdgeInsets.all(16),
                height: 60,
                width: 60,
                child: Stack(
                  children: [
                    Align(
                        alignment: Alignment.topLeft,
                        child: CircleAvatar(
                            key: UniqueKey(),
                            foregroundColor: HexColor(AppColors.appColorWhite),
                            backgroundColor: HexColor(AppColors.appColorWhite),
                            backgroundImage: NetworkImage(imageUrl),
                            radius: 52)),
                    Visibility(
                        visible: userType == "person",
                        child: Align(
                          alignment: Alignment.bottomRight,
                          child: Container(
                            padding: EdgeInsets.all(4),
                            decoration: BoxDecoration(
                                color: HexColor(AppColors.appColorWhite),
                                shape: BoxShape.circle),
                            child: Icon(
                              Icons.edit,
                              size: 12,
                              color: HexColor(AppColors.appColorBlack65),
                            ),
                          ),
                        )),
                  ],
                ),
              ),
            ),
            Expanded(
              child: GestureDetector(
                onTap: isFromProfile ? null : onClickProfile as void Function()?,
                child: Container(
                  margin: EdgeInsets.only(right: 10),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: <Widget>[
                      Align(
                        alignment: Alignment.topLeft,
                        child: Container(
                            child: Row(
                              mainAxisAlignment: MainAxisAlignment.start,
                              crossAxisAlignment: CrossAxisAlignment.center,
                              children: [
                                Flexible(
                                  child: Text(
                                    title ?? "",
                                    maxLines: 2,
                                    overflow: TextOverflow.ellipsis,
                                    style: styleElements
                                        .headline6ThemeScalable(context)
                                        .copyWith(
                                        fontWeight: FontWeight.bold,
                                        color: HexColor(AppColors.appColorBlack85)),
                                  ),
                                ),
                                Visibility(
                                  visible: isUserVerified,
                                  child: Padding(
                                    padding: const EdgeInsets.all(8.0),
                                    child: SizedBox(
                                      height: 16,
                                      width: 16,
                                      child: Container(
                                        child: Image(
                                          image:
                                          AssetImage('assets/appimages/check.png'),
                                        ),
                                      ),
                                    ),
                                  ),
                                )
                              ],
                            )),
                      ),
                      GestureDetector(
                        behavior: HitTestBehavior.translucent,
                        onTap: null,
                        child: Align(
                            alignment: Alignment.bottomLeft,
                            child: Row(
                              mainAxisAlignment: MainAxisAlignment.start,
                              crossAxisAlignment: CrossAxisAlignment.center,
                              children: [
                                Flexible(
                                  child: Text( "@Taraa",
                                      maxLines: 2,
                                      overflow: TextOverflow.ellipsis,
                                      style: styleElements
                                          .captionThemeScalable(context)),
                                )
                              ],
                            )),
                      ),
                      Visibility(
                        visible: showProgress ?? false,
                        child: Padding(
                          padding: const EdgeInsets.only(top: 4.0, bottom: 4.0),
                          child: Row(
                            children: [
                              Text(
                                "$progress%",
                                style: styleElements
                                    .bodyText1ThemeScalable(context)
                                    .copyWith(fontWeight: FontWeight.bold),
                              ),
                              Flexible(
                                child: LinearPercentIndicator(
                                  linearStrokeCap: LinearStrokeCap.roundAll,
                                  animation: true,
                                  animationDuration: 900,
                                  lineHeight: 12,
                                  percent: progress != null
                                      ? (progress!.toDouble() / 100)
                                      : 0.0,
                                  backgroundColor:
                                  HexColor(AppColors.pollBackground),
                                  progressColor: HexColor(AppColors.appMainColor)
                                      .withOpacity(0.75),
                                ),
                              ),
                            ],
                          ),
                        ),
                      ),

                      SizedBox(
                        height: 4,
                      )


                    ],
                  ),
                ),
              ),
            ),

          ],
        ),
        UserPopularityCard(
            textFive: '67',
            textThree: 'Status',
            textSix: '0',
            callback: () {},
            textTwo: 'Outstanding',
            textEight: 'Post Paid',
            textOne: 'Balance',
            textFour: 'Type',
            textSeven: 'Active')
      ],
    );
  }
}
